class HoldableItem:
    """Base class for game items which can be held by a player."""

    pass

    def can_combine(self, other):
        return False

    def combine(self, other):
        pass


class Plate(HoldableItem):
    def __init__(self):
        self.clean = True
        self.holds = None

        super().__init__()

    def can_combine(self, other: HoldableItem):
        return self.holds is None and not isinstance(other, Plate)

    def combine(self, other):
        self.holds = other

    def __repr__(self):
        return f"Plate({self.holds})"


class ProgressibleItem(HoldableItem):
    """Class for items which need to be processed (cut, cooked, ...)"""

    def __init__(self, steps_needed):
        self.progressed_steps = 0
        self.steps_needed = steps_needed
        self.finished = False
        super().__init__()

    def progress(self):
        """Progresses the item process as long as it is not finished."""
        if self.progressed_steps >= self.steps_needed:
            self.finished = True
            self.progressed_steps = 0
        if not self.finished:
            self.progressed_steps += 1

    def __repr__(self):
        if self.finished:
            return "CutTomato"
        else:
            return f"{self.__class__.__name__}({int(self.progressed_steps / self.steps_needed * 100)}%)"


class CuttableItem(ProgressibleItem):
    """Class of item which can be processed by the cutting board."""

    pass


class Tomato(CuttableItem):
    """Item class representing a tomato. Can be cut on the cutting board"""

    def can_combine(self, other):
        return False

    def __init__(self):
        super().__init__(steps_needed=1500)
